# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import dataclasses
import json  # type: ignore
import logging
from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
import warnings

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, rest_helpers, rest_streaming
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.requests import AuthorizedSession  # type: ignore
from google.protobuf import json_format
from requests import __version__ as requests_version

from google.apps.meet_v2beta.types import resource, service

from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
from .rest_base import _BaseConferenceRecordsServiceRestTransport

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault, None]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object, None]  # type: ignore

try:
    from google.api_core import client_logging  # type: ignore

    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
except ImportError:  # pragma: NO COVER
    CLIENT_LOGGING_SUPPORTED = False

_LOGGER = logging.getLogger(__name__)

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
    grpc_version=None,
    rest_version=f"requests@{requests_version}",
)


class ConferenceRecordsServiceRestInterceptor:
    """Interceptor for ConferenceRecordsService.

    Interceptors are used to manipulate requests, request metadata, and responses
    in arbitrary ways.
    Example use cases include:
    * Logging
    * Verifying requests according to service or custom semantics
    * Stripping extraneous information from responses

    These use cases and more can be enabled by injecting an
    instance of a custom subclass when constructing the ConferenceRecordsServiceRestTransport.

    .. code-block:: python
        class MyCustomConferenceRecordsServiceInterceptor(ConferenceRecordsServiceRestInterceptor):
            def pre_get_conference_record(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_get_conference_record(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_get_participant(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_get_participant(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_get_participant_session(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_get_participant_session(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_get_recording(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_get_recording(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_get_transcript(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_get_transcript(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_get_transcript_entry(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_get_transcript_entry(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_list_conference_records(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_list_conference_records(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_list_participants(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_list_participants(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_list_participant_sessions(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_list_participant_sessions(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_list_recordings(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_list_recordings(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_list_transcript_entries(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_list_transcript_entries(self, response):
                logging.log(f"Received response: {response}")
                return response

            def pre_list_transcripts(self, request, metadata):
                logging.log(f"Received request: {request}")
                return request, metadata

            def post_list_transcripts(self, response):
                logging.log(f"Received response: {response}")
                return response

        transport = ConferenceRecordsServiceRestTransport(interceptor=MyCustomConferenceRecordsServiceInterceptor())
        client = ConferenceRecordsServiceClient(transport=transport)


    """

    def pre_get_conference_record(
        self,
        request: service.GetConferenceRecordRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        service.GetConferenceRecordRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for get_conference_record

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_get_conference_record(
        self, response: resource.ConferenceRecord
    ) -> resource.ConferenceRecord:
        """Post-rpc interceptor for get_conference_record

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_get_participant(
        self,
        request: service.GetParticipantRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[service.GetParticipantRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
        """Pre-rpc interceptor for get_participant

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_get_participant(
        self, response: resource.Participant
    ) -> resource.Participant:
        """Post-rpc interceptor for get_participant

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_get_participant_session(
        self,
        request: service.GetParticipantSessionRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        service.GetParticipantSessionRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for get_participant_session

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_get_participant_session(
        self, response: resource.ParticipantSession
    ) -> resource.ParticipantSession:
        """Post-rpc interceptor for get_participant_session

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_get_recording(
        self,
        request: service.GetRecordingRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[service.GetRecordingRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
        """Pre-rpc interceptor for get_recording

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_get_recording(self, response: resource.Recording) -> resource.Recording:
        """Post-rpc interceptor for get_recording

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_get_transcript(
        self,
        request: service.GetTranscriptRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[service.GetTranscriptRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
        """Pre-rpc interceptor for get_transcript

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_get_transcript(self, response: resource.Transcript) -> resource.Transcript:
        """Post-rpc interceptor for get_transcript

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_get_transcript_entry(
        self,
        request: service.GetTranscriptEntryRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        service.GetTranscriptEntryRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for get_transcript_entry

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_get_transcript_entry(
        self, response: resource.TranscriptEntry
    ) -> resource.TranscriptEntry:
        """Post-rpc interceptor for get_transcript_entry

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_list_conference_records(
        self,
        request: service.ListConferenceRecordsRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        service.ListConferenceRecordsRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for list_conference_records

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_list_conference_records(
        self, response: service.ListConferenceRecordsResponse
    ) -> service.ListConferenceRecordsResponse:
        """Post-rpc interceptor for list_conference_records

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_list_participants(
        self,
        request: service.ListParticipantsRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        service.ListParticipantsRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for list_participants

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_list_participants(
        self, response: service.ListParticipantsResponse
    ) -> service.ListParticipantsResponse:
        """Post-rpc interceptor for list_participants

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_list_participant_sessions(
        self,
        request: service.ListParticipantSessionsRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        service.ListParticipantSessionsRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for list_participant_sessions

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_list_participant_sessions(
        self, response: service.ListParticipantSessionsResponse
    ) -> service.ListParticipantSessionsResponse:
        """Post-rpc interceptor for list_participant_sessions

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_list_recordings(
        self,
        request: service.ListRecordingsRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[service.ListRecordingsRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
        """Pre-rpc interceptor for list_recordings

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_list_recordings(
        self, response: service.ListRecordingsResponse
    ) -> service.ListRecordingsResponse:
        """Post-rpc interceptor for list_recordings

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_list_transcript_entries(
        self,
        request: service.ListTranscriptEntriesRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[
        service.ListTranscriptEntriesRequest, Sequence[Tuple[str, Union[str, bytes]]]
    ]:
        """Pre-rpc interceptor for list_transcript_entries

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_list_transcript_entries(
        self, response: service.ListTranscriptEntriesResponse
    ) -> service.ListTranscriptEntriesResponse:
        """Post-rpc interceptor for list_transcript_entries

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response

    def pre_list_transcripts(
        self,
        request: service.ListTranscriptsRequest,
        metadata: Sequence[Tuple[str, Union[str, bytes]]],
    ) -> Tuple[service.ListTranscriptsRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
        """Pre-rpc interceptor for list_transcripts

        Override in a subclass to manipulate the request or metadata
        before they are sent to the ConferenceRecordsService server.
        """
        return request, metadata

    def post_list_transcripts(
        self, response: service.ListTranscriptsResponse
    ) -> service.ListTranscriptsResponse:
        """Post-rpc interceptor for list_transcripts

        Override in a subclass to manipulate the response
        after it is returned by the ConferenceRecordsService server but before
        it is returned to user code.
        """
        return response


@dataclasses.dataclass
class ConferenceRecordsServiceRestStub:
    _session: AuthorizedSession
    _host: str
    _interceptor: ConferenceRecordsServiceRestInterceptor


class ConferenceRecordsServiceRestTransport(_BaseConferenceRecordsServiceRestTransport):
    """REST backend synchronous transport for ConferenceRecordsService.

    REST API for services dealing with conference records.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends JSON representations of protocol buffers over HTTP/1.1
    """

    def __init__(
        self,
        *,
        host: str = "meet.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        url_scheme: str = "https",
        interceptor: Optional[ConferenceRecordsServiceRestInterceptor] = None,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'meet.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.

            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional(Sequence[str])): A list of scopes. This argument is
                ignored if ``channel`` is provided.
            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
                certificate to configure mutual TLS HTTP channel. It is ignored
                if ``channel`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you are developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
            url_scheme: the protocol scheme for the API endpoint.  Normally
                "https", but for testing or local servers,
                "http" can be specified.
        """
        # Run the base constructor
        # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
        # TODO: When custom host (api_endpoint) is set, `scopes` must *also* be set on the
        # credentials object
        super().__init__(
            host=host,
            credentials=credentials,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            url_scheme=url_scheme,
            api_audience=api_audience,
        )
        self._session = AuthorizedSession(
            self._credentials, default_host=self.DEFAULT_HOST
        )
        if client_cert_source_for_mtls:
            self._session.configure_mtls_channel(client_cert_source_for_mtls)
        self._interceptor = interceptor or ConferenceRecordsServiceRestInterceptor()
        self._prep_wrapped_messages(client_info)

    class _GetConferenceRecord(
        _BaseConferenceRecordsServiceRestTransport._BaseGetConferenceRecord,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.GetConferenceRecord")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.GetConferenceRecordRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> resource.ConferenceRecord:
            r"""Call the get conference record method over HTTP.

            Args:
                request (~.service.GetConferenceRecordRequest):
                    The request object. Request to get a conference record.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.resource.ConferenceRecord:
                    `Developer
                Preview <https://developers.google.com/workspace/preview>`__.
                Single instance of a meeting held in a space.

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseGetConferenceRecord._get_http_options()
            )

            request, metadata = self._interceptor.pre_get_conference_record(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseGetConferenceRecord._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseGetConferenceRecord._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.GetConferenceRecord",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetConferenceRecord",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = ConferenceRecordsServiceRestTransport._GetConferenceRecord._get_response(
                self._host,
                metadata,
                query_params,
                self._session,
                timeout,
                transcoded_request,
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = resource.ConferenceRecord()
            pb_resp = resource.ConferenceRecord.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_get_conference_record(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = resource.ConferenceRecord.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.get_conference_record",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetConferenceRecord",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _GetParticipant(
        _BaseConferenceRecordsServiceRestTransport._BaseGetParticipant,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.GetParticipant")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.GetParticipantRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> resource.Participant:
            r"""Call the get participant method over HTTP.

            Args:
                request (~.service.GetParticipantRequest):
                    The request object. Request to get a Participant.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.resource.Participant:
                    `Developer
                Preview <https://developers.google.com/workspace/preview>`__.
                User who attended or is attending a conference.

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseGetParticipant._get_http_options()
            )

            request, metadata = self._interceptor.pre_get_participant(request, metadata)
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseGetParticipant._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseGetParticipant._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.GetParticipant",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetParticipant",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                ConferenceRecordsServiceRestTransport._GetParticipant._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = resource.Participant()
            pb_resp = resource.Participant.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_get_participant(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = resource.Participant.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.get_participant",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetParticipant",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _GetParticipantSession(
        _BaseConferenceRecordsServiceRestTransport._BaseGetParticipantSession,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.GetParticipantSession")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.GetParticipantSessionRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> resource.ParticipantSession:
            r"""Call the get participant session method over HTTP.

            Args:
                request (~.service.GetParticipantSessionRequest):
                    The request object. Request to get a participant session.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.resource.ParticipantSession:
                    `Developer
                Preview <https://developers.google.com/workspace/preview>`__.
                Refers to each unique join/leave session when a user
                joins a conference from a device. Note that any time a
                user joins the conference a new unique ID is assigned.
                That means if a user joins a space multiple times from
                the same device, they're assigned different IDs, and are
                also be treated as different participant sessions.

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseGetParticipantSession._get_http_options()
            )

            request, metadata = self._interceptor.pre_get_participant_session(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseGetParticipantSession._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseGetParticipantSession._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.GetParticipantSession",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetParticipantSession",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = ConferenceRecordsServiceRestTransport._GetParticipantSession._get_response(
                self._host,
                metadata,
                query_params,
                self._session,
                timeout,
                transcoded_request,
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = resource.ParticipantSession()
            pb_resp = resource.ParticipantSession.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_get_participant_session(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = resource.ParticipantSession.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.get_participant_session",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetParticipantSession",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _GetRecording(
        _BaseConferenceRecordsServiceRestTransport._BaseGetRecording,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.GetRecording")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.GetRecordingRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> resource.Recording:
            r"""Call the get recording method over HTTP.

            Args:
                request (~.service.GetRecordingRequest):
                    The request object. Request message for GetRecording
                method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.resource.Recording:
                    `Developer
                Preview <https://developers.google.com/workspace/preview>`__.
                Metadata about a recording created during a conference.

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseGetRecording._get_http_options()
            )

            request, metadata = self._interceptor.pre_get_recording(request, metadata)
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseGetRecording._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseGetRecording._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.GetRecording",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetRecording",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                ConferenceRecordsServiceRestTransport._GetRecording._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = resource.Recording()
            pb_resp = resource.Recording.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_get_recording(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = resource.Recording.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.get_recording",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetRecording",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _GetTranscript(
        _BaseConferenceRecordsServiceRestTransport._BaseGetTranscript,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.GetTranscript")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.GetTranscriptRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> resource.Transcript:
            r"""Call the get transcript method over HTTP.

            Args:
                request (~.service.GetTranscriptRequest):
                    The request object. Request for GetTranscript method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.resource.Transcript:
                    `Developer
                Preview <https://developers.google.com/workspace/preview>`__.
                Metadata for a transcript generated from a conference.
                It refers to the ASR (Automatic Speech Recognition)
                result of user's speech during the conference.

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseGetTranscript._get_http_options()
            )

            request, metadata = self._interceptor.pre_get_transcript(request, metadata)
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseGetTranscript._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseGetTranscript._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.GetTranscript",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetTranscript",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                ConferenceRecordsServiceRestTransport._GetTranscript._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = resource.Transcript()
            pb_resp = resource.Transcript.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_get_transcript(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = resource.Transcript.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.get_transcript",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetTranscript",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _GetTranscriptEntry(
        _BaseConferenceRecordsServiceRestTransport._BaseGetTranscriptEntry,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.GetTranscriptEntry")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.GetTranscriptEntryRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> resource.TranscriptEntry:
            r"""Call the get transcript entry method over HTTP.

            Args:
                request (~.service.GetTranscriptEntryRequest):
                    The request object. Request for GetTranscriptEntry
                method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.resource.TranscriptEntry:
                    `Developer
                Preview <https://developers.google.com/workspace/preview>`__.
                Single entry for one user’s speech during a transcript
                session.

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseGetTranscriptEntry._get_http_options()
            )

            request, metadata = self._interceptor.pre_get_transcript_entry(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseGetTranscriptEntry._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseGetTranscriptEntry._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.GetTranscriptEntry",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetTranscriptEntry",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                ConferenceRecordsServiceRestTransport._GetTranscriptEntry._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = resource.TranscriptEntry()
            pb_resp = resource.TranscriptEntry.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_get_transcript_entry(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = resource.TranscriptEntry.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.get_transcript_entry",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "GetTranscriptEntry",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _ListConferenceRecords(
        _BaseConferenceRecordsServiceRestTransport._BaseListConferenceRecords,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.ListConferenceRecords")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.ListConferenceRecordsRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> service.ListConferenceRecordsResponse:
            r"""Call the list conference records method over HTTP.

            Args:
                request (~.service.ListConferenceRecordsRequest):
                    The request object. Request to fetch list of conference
                records per user.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.service.ListConferenceRecordsResponse:
                    Response of ListConferenceRecords
                method.

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseListConferenceRecords._get_http_options()
            )

            request, metadata = self._interceptor.pre_list_conference_records(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseListConferenceRecords._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseListConferenceRecords._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.ListConferenceRecords",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListConferenceRecords",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = ConferenceRecordsServiceRestTransport._ListConferenceRecords._get_response(
                self._host,
                metadata,
                query_params,
                self._session,
                timeout,
                transcoded_request,
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = service.ListConferenceRecordsResponse()
            pb_resp = service.ListConferenceRecordsResponse.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_list_conference_records(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = service.ListConferenceRecordsResponse.to_json(
                        response
                    )
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.list_conference_records",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListConferenceRecords",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _ListParticipants(
        _BaseConferenceRecordsServiceRestTransport._BaseListParticipants,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.ListParticipants")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.ListParticipantsRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> service.ListParticipantsResponse:
            r"""Call the list participants method over HTTP.

            Args:
                request (~.service.ListParticipantsRequest):
                    The request object. Request to fetch list of participant
                per conference.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.service.ListParticipantsResponse:
                    Response of ListParticipants method.
            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseListParticipants._get_http_options()
            )

            request, metadata = self._interceptor.pre_list_participants(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseListParticipants._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseListParticipants._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.ListParticipants",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListParticipants",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                ConferenceRecordsServiceRestTransport._ListParticipants._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = service.ListParticipantsResponse()
            pb_resp = service.ListParticipantsResponse.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_list_participants(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = service.ListParticipantsResponse.to_json(
                        response
                    )
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.list_participants",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListParticipants",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _ListParticipantSessions(
        _BaseConferenceRecordsServiceRestTransport._BaseListParticipantSessions,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.ListParticipantSessions")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.ListParticipantSessionsRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> service.ListParticipantSessionsResponse:
            r"""Call the list participant sessions method over HTTP.

            Args:
                request (~.service.ListParticipantSessionsRequest):
                    The request object. Request to fetch list of participant
                sessions per conference record per
                participant.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.service.ListParticipantSessionsResponse:
                    Response of ListParticipants method.
            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseListParticipantSessions._get_http_options()
            )

            request, metadata = self._interceptor.pre_list_participant_sessions(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseListParticipantSessions._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseListParticipantSessions._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.ListParticipantSessions",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListParticipantSessions",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = ConferenceRecordsServiceRestTransport._ListParticipantSessions._get_response(
                self._host,
                metadata,
                query_params,
                self._session,
                timeout,
                transcoded_request,
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = service.ListParticipantSessionsResponse()
            pb_resp = service.ListParticipantSessionsResponse.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_list_participant_sessions(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = service.ListParticipantSessionsResponse.to_json(
                        response
                    )
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.list_participant_sessions",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListParticipantSessions",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _ListRecordings(
        _BaseConferenceRecordsServiceRestTransport._BaseListRecordings,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.ListRecordings")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.ListRecordingsRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> service.ListRecordingsResponse:
            r"""Call the list recordings method over HTTP.

            Args:
                request (~.service.ListRecordingsRequest):
                    The request object. Request for ListRecordings method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.service.ListRecordingsResponse:
                    Response for ListRecordings method.
            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseListRecordings._get_http_options()
            )

            request, metadata = self._interceptor.pre_list_recordings(request, metadata)
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseListRecordings._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseListRecordings._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.ListRecordings",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListRecordings",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                ConferenceRecordsServiceRestTransport._ListRecordings._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = service.ListRecordingsResponse()
            pb_resp = service.ListRecordingsResponse.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_list_recordings(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = service.ListRecordingsResponse.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.list_recordings",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListRecordings",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _ListTranscriptEntries(
        _BaseConferenceRecordsServiceRestTransport._BaseListTranscriptEntries,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.ListTranscriptEntries")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.ListTranscriptEntriesRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> service.ListTranscriptEntriesResponse:
            r"""Call the list transcript entries method over HTTP.

            Args:
                request (~.service.ListTranscriptEntriesRequest):
                    The request object. Request for ListTranscriptEntries
                method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.service.ListTranscriptEntriesResponse:
                    Response for ListTranscriptEntries
                method

            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseListTranscriptEntries._get_http_options()
            )

            request, metadata = self._interceptor.pre_list_transcript_entries(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseListTranscriptEntries._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseListTranscriptEntries._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.ListTranscriptEntries",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListTranscriptEntries",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = ConferenceRecordsServiceRestTransport._ListTranscriptEntries._get_response(
                self._host,
                metadata,
                query_params,
                self._session,
                timeout,
                transcoded_request,
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = service.ListTranscriptEntriesResponse()
            pb_resp = service.ListTranscriptEntriesResponse.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_list_transcript_entries(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = service.ListTranscriptEntriesResponse.to_json(
                        response
                    )
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.list_transcript_entries",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListTranscriptEntries",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    class _ListTranscripts(
        _BaseConferenceRecordsServiceRestTransport._BaseListTranscripts,
        ConferenceRecordsServiceRestStub,
    ):
        def __hash__(self):
            return hash("ConferenceRecordsServiceRestTransport.ListTranscripts")

        @staticmethod
        def _get_response(
            host,
            metadata,
            query_params,
            session,
            timeout,
            transcoded_request,
            body=None,
        ):
            uri = transcoded_request["uri"]
            method = transcoded_request["method"]
            headers = dict(metadata)
            headers["Content-Type"] = "application/json"
            response = getattr(session, method)(
                "{host}{uri}".format(host=host, uri=uri),
                timeout=timeout,
                headers=headers,
                params=rest_helpers.flatten_query_params(query_params, strict=True),
            )
            return response

        def __call__(
            self,
            request: service.ListTranscriptsRequest,
            *,
            retry: OptionalRetry = gapic_v1.method.DEFAULT,
            timeout: Optional[float] = None,
            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
        ) -> service.ListTranscriptsResponse:
            r"""Call the list transcripts method over HTTP.

            Args:
                request (~.service.ListTranscriptsRequest):
                    The request object. Request for ListTranscripts method.
                retry (google.api_core.retry.Retry): Designation of what errors, if any,
                    should be retried.
                timeout (float): The timeout for this request.
                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                    sent along with the request as metadata. Normally, each value must be of type `str`,
                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
                    be of type `bytes`.

            Returns:
                ~.service.ListTranscriptsResponse:
                    Response for ListTranscripts method.
            """

            http_options = (
                _BaseConferenceRecordsServiceRestTransport._BaseListTranscripts._get_http_options()
            )

            request, metadata = self._interceptor.pre_list_transcripts(
                request, metadata
            )
            transcoded_request = _BaseConferenceRecordsServiceRestTransport._BaseListTranscripts._get_transcoded_request(
                http_options, request
            )

            # Jsonify the query params
            query_params = _BaseConferenceRecordsServiceRestTransport._BaseListTranscripts._get_query_params_json(
                transcoded_request
            )

            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                request_url = "{host}{uri}".format(
                    host=self._host, uri=transcoded_request["uri"]
                )
                method = transcoded_request["method"]
                try:
                    request_payload = type(request).to_json(request)
                except:
                    request_payload = None
                http_request = {
                    "payload": request_payload,
                    "requestMethod": method,
                    "requestUrl": request_url,
                    "headers": dict(metadata),
                }
                _LOGGER.debug(
                    f"Sending request for google.apps.meet_v2beta.ConferenceRecordsServiceClient.ListTranscripts",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListTranscripts",
                        "httpRequest": http_request,
                        "metadata": http_request["headers"],
                    },
                )

            # Send the request
            response = (
                ConferenceRecordsServiceRestTransport._ListTranscripts._get_response(
                    self._host,
                    metadata,
                    query_params,
                    self._session,
                    timeout,
                    transcoded_request,
                )
            )

            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
            # subclass.
            if response.status_code >= 400:
                raise core_exceptions.from_http_response(response)

            # Return the response
            resp = service.ListTranscriptsResponse()
            pb_resp = service.ListTranscriptsResponse.pb(resp)

            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)

            resp = self._interceptor.post_list_transcripts(resp)
            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                logging.DEBUG
            ):  # pragma: NO COVER
                try:
                    response_payload = service.ListTranscriptsResponse.to_json(response)
                except:
                    response_payload = None
                http_response = {
                    "payload": response_payload,
                    "headers": dict(response.headers),
                    "status": response.status_code,
                }
                _LOGGER.debug(
                    "Received response for google.apps.meet_v2beta.ConferenceRecordsServiceClient.list_transcripts",
                    extra={
                        "serviceName": "google.apps.meet.v2beta.ConferenceRecordsService",
                        "rpcName": "ListTranscripts",
                        "metadata": http_response["headers"],
                        "httpResponse": http_response,
                    },
                )
            return resp

    @property
    def get_conference_record(
        self,
    ) -> Callable[[service.GetConferenceRecordRequest], resource.ConferenceRecord]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._GetConferenceRecord(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def get_participant(
        self,
    ) -> Callable[[service.GetParticipantRequest], resource.Participant]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._GetParticipant(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def get_participant_session(
        self,
    ) -> Callable[[service.GetParticipantSessionRequest], resource.ParticipantSession]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._GetParticipantSession(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def get_recording(
        self,
    ) -> Callable[[service.GetRecordingRequest], resource.Recording]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._GetRecording(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def get_transcript(
        self,
    ) -> Callable[[service.GetTranscriptRequest], resource.Transcript]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._GetTranscript(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def get_transcript_entry(
        self,
    ) -> Callable[[service.GetTranscriptEntryRequest], resource.TranscriptEntry]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._GetTranscriptEntry(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def list_conference_records(
        self,
    ) -> Callable[
        [service.ListConferenceRecordsRequest], service.ListConferenceRecordsResponse
    ]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._ListConferenceRecords(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def list_participants(
        self,
    ) -> Callable[[service.ListParticipantsRequest], service.ListParticipantsResponse]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._ListParticipants(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def list_participant_sessions(
        self,
    ) -> Callable[
        [service.ListParticipantSessionsRequest],
        service.ListParticipantSessionsResponse,
    ]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._ListParticipantSessions(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def list_recordings(
        self,
    ) -> Callable[[service.ListRecordingsRequest], service.ListRecordingsResponse]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._ListRecordings(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def list_transcript_entries(
        self,
    ) -> Callable[
        [service.ListTranscriptEntriesRequest], service.ListTranscriptEntriesResponse
    ]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._ListTranscriptEntries(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def list_transcripts(
        self,
    ) -> Callable[[service.ListTranscriptsRequest], service.ListTranscriptsResponse]:
        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
        # In C++ this would require a dynamic_cast
        return self._ListTranscripts(self._session, self._host, self._interceptor)  # type: ignore

    @property
    def kind(self) -> str:
        return "rest"

    def close(self):
        self._session.close()


__all__ = ("ConferenceRecordsServiceRestTransport",)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.apps.meet.v2",
    manifest={
        "Space",
        "ActiveConference",
        "SpaceConfig",
        "ConferenceRecord",
        "Participant",
        "ParticipantSession",
        "SignedinUser",
        "AnonymousUser",
        "PhoneUser",
        "Recording",
        "DriveDestination",
        "Transcript",
        "DocsDestination",
        "TranscriptEntry",
    },
)


class Space(proto.Message):
    r"""Virtual place where conferences are held. Only one active
    conference can be held in one space at any given time.

    Attributes:
        name (str):
            Immutable. Resource name of the space. Format:
            ``spaces/{space}``
        meeting_uri (str):
            Output only. URI used to join meetings, such as
            ``https://meet.google.com/abc-mnop-xyz``.
        meeting_code (str):
            Output only. Type friendly code to join the meeting. Format:
            ``[a-z]+-[a-z]+-[a-z]+`` such as ``abc-mnop-xyz``. The
            maximum length is 128 characters. Can only be used as an
            alias of the space ID to get the space.
        config (google.apps.meet_v2.types.SpaceConfig):
            Configuration pertaining to the meeting
            space.
        active_conference (google.apps.meet_v2.types.ActiveConference):
            Active conference, if it exists.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    meeting_uri: str = proto.Field(
        proto.STRING,
        number=2,
    )
    meeting_code: str = proto.Field(
        proto.STRING,
        number=3,
    )
    config: "SpaceConfig" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="SpaceConfig",
    )
    active_conference: "ActiveConference" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="ActiveConference",
    )


class ActiveConference(proto.Message):
    r"""Active conference.

    Attributes:
        conference_record (str):
            Output only. Reference to 'ConferenceRecord' resource.
            Format: ``conferenceRecords/{conference_record}`` where
            ``{conference_record}`` is a unique ID for each instance of
            a call within a space.
    """

    conference_record: str = proto.Field(
        proto.STRING,
        number=1,
    )


class SpaceConfig(proto.Message):
    r"""The configuration pertaining to a meeting space.

    Attributes:
        access_type (google.apps.meet_v2.types.SpaceConfig.AccessType):
            Access type of the meeting space that
            determines who can join without knocking.
            Default: The user's default access settings.
            Controlled by the user's admin for enterprise
            users or RESTRICTED.
        entry_point_access (google.apps.meet_v2.types.SpaceConfig.EntryPointAccess):
            Defines the entry points that can be used to
            join meetings hosted in this meeting space.
            Default: EntryPointAccess.ALL
    """

    class AccessType(proto.Enum):
        r"""Possible access types for a meeting space.

        Values:
            ACCESS_TYPE_UNSPECIFIED (0):
                Default value specified by the user's
                organization. Note: This is never returned, as
                the configured access type is returned instead.
            OPEN (1):
                Anyone with the join information (for
                example, the URL or phone access information)
                can join without knocking.
            TRUSTED (2):
                Members of the host's organization, invited
                external users, and dial-in users can join
                without knocking. Everyone else must knock.
            RESTRICTED (3):
                Only invitees can join without knocking.
                Everyone else must knock.
        """
        ACCESS_TYPE_UNSPECIFIED = 0
        OPEN = 1
        TRUSTED = 2
        RESTRICTED = 3

    class EntryPointAccess(proto.Enum):
        r"""Entry points that can be used to join a meeting. Example:
        ``meet.google.com``, the Meet Embed SDK Web, or a mobile
        application.

        Values:
            ENTRY_POINT_ACCESS_UNSPECIFIED (0):
                Unused.
            ALL (1):
                All entry points are allowed.
            CREATOR_APP_ONLY (2):
                Only entry points owned by the Google Cloud
                project that created the space can be used to
                join meetings in this space. Apps can use the
                Meet Embed SDK Web or mobile Meet SDKs to create
                owned entry points.
        """
        ENTRY_POINT_ACCESS_UNSPECIFIED = 0
        ALL = 1
        CREATOR_APP_ONLY = 2

    access_type: AccessType = proto.Field(
        proto.ENUM,
        number=1,
        enum=AccessType,
    )
    entry_point_access: EntryPointAccess = proto.Field(
        proto.ENUM,
        number=2,
        enum=EntryPointAccess,
    )


class ConferenceRecord(proto.Message):
    r"""Single instance of a meeting held in a space.

    Attributes:
        name (str):
            Identifier. Resource name of the conference record. Format:
            ``conferenceRecords/{conference_record}`` where
            ``{conference_record}`` is a unique ID for each instance of
            a call within a space.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the conference
            started. Always set.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the conference
            ended. Set for past conferences. Unset if the
            conference is ongoing.
        expire_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Server enforced expiration time
            for when this conference record resource is
            deleted. The resource is deleted 30 days after
            the conference ends.
        space (str):
            Output only. The space where the conference
            was held.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    expire_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    space: str = proto.Field(
        proto.STRING,
        number=5,
    )


class Participant(proto.Message):
    r"""User who attended or is attending a conference.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        signedin_user (google.apps.meet_v2.types.SignedinUser):
            Signed-in user.

            This field is a member of `oneof`_ ``user``.
        anonymous_user (google.apps.meet_v2.types.AnonymousUser):
            Anonymous user.

            This field is a member of `oneof`_ ``user``.
        phone_user (google.apps.meet_v2.types.PhoneUser):
            User calling from their phone.

            This field is a member of `oneof`_ ``user``.
        name (str):
            Output only. Resource name of the participant. Format:
            ``conferenceRecords/{conference_record}/participants/{participant}``
        earliest_start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when the participant first
            joined the meeting.
        latest_end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time when the participant left
            the meeting for the last time. This can be null
            if it's an active meeting.
    """

    signedin_user: "SignedinUser" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="user",
        message="SignedinUser",
    )
    anonymous_user: "AnonymousUser" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="user",
        message="AnonymousUser",
    )
    phone_user: "PhoneUser" = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="user",
        message="PhoneUser",
    )
    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    earliest_start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    latest_end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        message=timestamp_pb2.Timestamp,
    )


class ParticipantSession(proto.Message):
    r"""Refers to each unique join or leave session when a user joins
    a conference from a device. Note that any time a user joins the
    conference a new unique ID is assigned. That means if a user
    joins a space multiple times from the same device, they're
    assigned different IDs, and are also be treated as different
    participant sessions.

    Attributes:
        name (str):
            Identifier. Session id.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the user session
            starts.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the user session
            ends. Unset if the user session hasn’t ended.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )


class SignedinUser(proto.Message):
    r"""A signed-in user can be:

    a) An individual joining from a personal computer, mobile
    device, or through companion mode.
    b) A robot account used by conference room devices.

    Attributes:
        user (str):
            Output only. Unique ID for the user. Interoperable with
            Admin SDK API and People API. Format: ``users/{user}``
        display_name (str):
            Output only. For a personal device, it's the
            user's first name and last name. For a robot
            account, it's the administrator-specified device
            name. For example, "Altostrat Room".
    """

    user: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )


class AnonymousUser(proto.Message):
    r"""User who joins anonymously (meaning not signed into a Google
    Account).

    Attributes:
        display_name (str):
            Output only. User provided name when they
            join a conference anonymously.
    """

    display_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class PhoneUser(proto.Message):
    r"""User dialing in from a phone where the user's identity is
    unknown because they haven't signed in with a Google Account.

    Attributes:
        display_name (str):
            Output only. Partially redacted user's phone
            number when calling.
    """

    display_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class Recording(proto.Message):
    r"""Metadata about a recording created during a conference.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        drive_destination (google.apps.meet_v2.types.DriveDestination):
            Output only. Recording is saved to Google Drive as an MP4
            file. The ``drive_destination`` includes the Drive
            ``fileId`` that can be used to download the file using the
            ``files.get`` method of the Drive API.

            This field is a member of `oneof`_ ``destination``.
        name (str):
            Output only. Resource name of the recording. Format:
            ``conferenceRecords/{conference_record}/recordings/{recording}``
            where ``{recording}`` is a 1:1 mapping to each unique
            recording session during the conference.
        state (google.apps.meet_v2.types.Recording.State):
            Output only. Current state.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the recording
            started.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the recording
            ended.
    """

    class State(proto.Enum):
        r"""Current state of the recording session.

        Values:
            STATE_UNSPECIFIED (0):
                Default, never used.
            STARTED (1):
                An active recording session has started.
            ENDED (2):
                This recording session has ended, but the
                recording file hasn't been generated yet.
            FILE_GENERATED (3):
                Recording file is generated and ready to
                download.
        """
        STATE_UNSPECIFIED = 0
        STARTED = 1
        ENDED = 2
        FILE_GENERATED = 3

    drive_destination: "DriveDestination" = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="destination",
        message="DriveDestination",
    )
    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=3,
        enum=State,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )


class DriveDestination(proto.Message):
    r"""Export location where a recording file is saved in Google
    Drive.

    Attributes:
        file (str):
            Output only. The ``fileId`` for the underlying MP4 file. For
            example, "1kuceFZohVoCh6FulBHxwy6I15Ogpc4hP". Use
            ``$ GET https://www.googleapis.com/drive/v3/files/{$fileId}?alt=media``
            to download the blob. For more information, see
            https://developers.google.com/drive/api/v3/reference/files/get.
        export_uri (str):
            Output only. Link used to play back the recording file in
            the browser. For example,
            ``https://drive.google.com/file/d/{$fileId}/view``.
    """

    file: str = proto.Field(
        proto.STRING,
        number=1,
    )
    export_uri: str = proto.Field(
        proto.STRING,
        number=2,
    )


class Transcript(proto.Message):
    r"""Metadata for a transcript generated from a conference. It
    refers to the ASR (Automatic Speech Recognition) result of
    user's speech during the conference.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        docs_destination (google.apps.meet_v2.types.DocsDestination):
            Output only. Where the Google Docs transcript
            is saved.

            This field is a member of `oneof`_ ``destination``.
        name (str):
            Output only. Resource name of the transcript. Format:
            ``conferenceRecords/{conference_record}/transcripts/{transcript}``,
            where ``{transcript}`` is a 1:1 mapping to each unique
            transcription session of the conference.
        state (google.apps.meet_v2.types.Transcript.State):
            Output only. Current state.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the transcript
            started.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the transcript
            stopped.
    """

    class State(proto.Enum):
        r"""Current state of the transcript session.

        Values:
            STATE_UNSPECIFIED (0):
                Default, never used.
            STARTED (1):
                An active transcript session has started.
            ENDED (2):
                This transcript session has ended, but the
                transcript file hasn't been generated yet.
            FILE_GENERATED (3):
                Transcript file is generated and ready to
                download.
        """
        STATE_UNSPECIFIED = 0
        STARTED = 1
        ENDED = 2
        FILE_GENERATED = 3

    docs_destination: "DocsDestination" = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="destination",
        message="DocsDestination",
    )
    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=3,
        enum=State,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )


class DocsDestination(proto.Message):
    r"""Google Docs location where the transcript file is saved.

    Attributes:
        document (str):
            Output only. The document ID for the underlying Google Docs
            transcript file. For example,
            "1kuceFZohVoCh6FulBHxwy6I15Ogpc4hP". Use the
            ``documents.get`` method of the Google Docs API
            (https://developers.google.com/docs/api/reference/rest/v1/documents/get)
            to fetch the content.
        export_uri (str):
            Output only. URI for the Google Docs transcript file. Use
            ``https://docs.google.com/document/d/{$DocumentId}/view`` to
            browse the transcript in the browser.
    """

    document: str = proto.Field(
        proto.STRING,
        number=1,
    )
    export_uri: str = proto.Field(
        proto.STRING,
        number=2,
    )


class TranscriptEntry(proto.Message):
    r"""Single entry for one user’s speech during a transcript
    session.

    Attributes:
        name (str):
            Output only. Resource name of the entry. Format:
            "conferenceRecords/{conference_record}/transcripts/{transcript}/entries/{entry}".
        participant (str):
            Output only. Refers to the participant who
            speaks.
        text (str):
            Output only. The transcribed text of the
            participant's voice, at maximum 10K words. Note
            that the limit is subject to change.
        language_code (str):
            Output only. Language of spoken text, such as
            "en-US". IETF BCP 47 syntax
            (https://tools.ietf.org/html/bcp47)
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the transcript
            entry started.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp when the transcript
            entry ended.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    participant: str = proto.Field(
        proto.STRING,
        number=2,
    )
    text: str = proto.Field(
        proto.STRING,
        number=3,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=4,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.apps.meet_v2beta.types import resource

__protobuf__ = proto.module(
    package="google.apps.meet.v2beta",
    manifest={
        "CreateSpaceRequest",
        "GetSpaceRequest",
        "UpdateSpaceRequest",
        "EndActiveConferenceRequest",
        "GetConferenceRecordRequest",
        "ListConferenceRecordsRequest",
        "ListConferenceRecordsResponse",
        "GetParticipantRequest",
        "ListParticipantsRequest",
        "ListParticipantsResponse",
        "GetParticipantSessionRequest",
        "ListParticipantSessionsRequest",
        "ListParticipantSessionsResponse",
        "GetRecordingRequest",
        "ListRecordingsRequest",
        "ListRecordingsResponse",
        "GetTranscriptRequest",
        "ListTranscriptsRequest",
        "ListTranscriptsResponse",
        "GetTranscriptEntryRequest",
        "ListTranscriptEntriesRequest",
        "ListTranscriptEntriesResponse",
    },
)


class CreateSpaceRequest(proto.Message):
    r"""Request to create a space.

    Attributes:
        space (google.apps.meet_v2beta.types.Space):
            Space to be created. As of May 2023, the
            input space can be empty. Later on the input
            space can be non-empty when space configuration
            is introduced.
    """

    space: resource.Space = proto.Field(
        proto.MESSAGE,
        number=1,
        message=resource.Space,
    )


class GetSpaceRequest(proto.Message):
    r"""Request to get a space.

    Attributes:
        name (str):
            Required. Resource name of the space.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateSpaceRequest(proto.Message):
    r"""Request to update a space.

    Attributes:
        space (google.apps.meet_v2beta.types.Space):
            Required. Space to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Optional. Field mask used to specify the fields to be
            updated in the space. If update_mask isn't provided, it
            defaults to '*' and updates all fields provided in the
            request, including deleting fields not set in the request.
    """

    space: resource.Space = proto.Field(
        proto.MESSAGE,
        number=1,
        message=resource.Space,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class EndActiveConferenceRequest(proto.Message):
    r"""Request to end an ongoing conference of a space.

    Attributes:
        name (str):
            Required. Resource name of the space.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class GetConferenceRecordRequest(proto.Message):
    r"""Request to get a conference record.

    Attributes:
        name (str):
            Required. Resource name of the conference.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListConferenceRecordsRequest(proto.Message):
    r"""Request to fetch list of conference records per user.

    Attributes:
        page_size (int):
            Optional. Maximum number of conference
            records to return. The service might return
            fewer than this value. If unspecified, at most
            25 conference records are returned. The maximum
            value is 100; values above 100 are coerced to
            100. Maximum might change in the future.
        page_token (str):
            Optional. Page token returned from previous
            List Call.
        filter (str):
            Optional. User specified filtering condition in EBNF format.
            The following are the filterable fields:

            -  ``space.meeting_code``
            -  ``space.name``
            -  ``start_time``
            -  ``end_time``

            For example, ``space.meeting_code = "abc-mnop-xyz"``.
    """

    page_size: int = proto.Field(
        proto.INT32,
        number=1,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListConferenceRecordsResponse(proto.Message):
    r"""Response of ListConferenceRecords method.

    Attributes:
        conference_records (MutableSequence[google.apps.meet_v2beta.types.ConferenceRecord]):
            List of conferences in one page.
        next_page_token (str):
            Token to be circulated back for further List
            call if current List does NOT include all the
            Conferences. Unset if all conferences have been
            returned.
    """

    @property
    def raw_page(self):
        return self

    conference_records: MutableSequence[
        resource.ConferenceRecord
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=resource.ConferenceRecord,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetParticipantRequest(proto.Message):
    r"""Request to get a Participant.

    Attributes:
        name (str):
            Required. Resource name of the participant.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListParticipantsRequest(proto.Message):
    r"""Request to fetch list of participant per conference.

    Attributes:
        parent (str):
            Required. Format: ``conferenceRecords/{conference_record}``
        page_size (int):
            Maximum number of participants to return. The
            service might return fewer than this value.
            If unspecified, at most 100 participants are
            returned. The maximum value is 250; values above
            250 are coerced to 250. Maximum might change in
            the future.
        page_token (str):
            Page token returned from previous List Call.
        filter (str):
            Optional. User specified filtering condition in EBNF format.
            The following are the filterable fields:

            -  ``earliest_start_time``
            -  ``latest_end_time``

            For example, ``latest_end_time IS NULL`` returns active
            participants in the conference.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListParticipantsResponse(proto.Message):
    r"""Response of ListParticipants method.

    Attributes:
        participants (MutableSequence[google.apps.meet_v2beta.types.Participant]):
            List of participants in one page.
        next_page_token (str):
            Token to be circulated back for further List
            call if current List doesn't include all the
            participants. Unset if all participants are
            returned.
        total_size (int):
            Total, exact number of ``participants``. By default, this
            field isn't included in the response. Set the field mask in
            `SystemParameterContext <https://cloud.google.com/apis/docs/system-parameters>`__
            to receive this field in the response.
    """

    @property
    def raw_page(self):
        return self

    participants: MutableSequence[resource.Participant] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=resource.Participant,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


class GetParticipantSessionRequest(proto.Message):
    r"""Request to get a participant session.

    Attributes:
        name (str):
            Required. Resource name of the participant.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListParticipantSessionsRequest(proto.Message):
    r"""Request to fetch list of participant sessions per conference
    record per participant.

    Attributes:
        parent (str):
            Required. Format:
            ``conferenceRecords/{conference_record}/participants/{participant}``
        page_size (int):
            Optional. Maximum number of participant
            sessions to return. The service might return
            fewer than this value. If unspecified, at most
            100 participants are returned. The maximum value
            is 250; values above 250 are coerced to 250.
            Maximum might change in the future.
        page_token (str):
            Optional. Page token returned from previous
            List Call.
        filter (str):
            Optional. User specified filtering condition in EBNF format.
            The following are the filterable fields:

            -  ``start_time``
            -  ``end_time``

            For example, ``end_time IS NULL`` returns active participant
            sessions in the conference record.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListParticipantSessionsResponse(proto.Message):
    r"""Response of ListParticipants method.

    Attributes:
        participant_sessions (MutableSequence[google.apps.meet_v2beta.types.ParticipantSession]):
            List of participants in one page.
        next_page_token (str):
            Token to be circulated back for further List
            call if current List doesn't include all the
            participants. Unset if all participants are
            returned.
    """

    @property
    def raw_page(self):
        return self

    participant_sessions: MutableSequence[
        resource.ParticipantSession
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=resource.ParticipantSession,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetRecordingRequest(proto.Message):
    r"""Request message for GetRecording method.

    Attributes:
        name (str):
            Required. Resource name of the recording.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListRecordingsRequest(proto.Message):
    r"""Request for ListRecordings method.

    Attributes:
        parent (str):
            Required. Format: ``conferenceRecords/{conference_record}``
        page_size (int):
            Maximum number of recordings to return. The
            service might return fewer than this value.
            If unspecified, at most 10 recordings are
            returned. The maximum value is 100; values above
            100 are coerced to 100. Maximum might change in
            the future.
        page_token (str):
            Page token returned from previous List Call.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListRecordingsResponse(proto.Message):
    r"""Response for ListRecordings method.

    Attributes:
        recordings (MutableSequence[google.apps.meet_v2beta.types.Recording]):
            List of recordings in one page.
        next_page_token (str):
            Token to be circulated back for further List
            call if current List doesn't include all the
            recordings. Unset if all recordings are
            returned.
    """

    @property
    def raw_page(self):
        return self

    recordings: MutableSequence[resource.Recording] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=resource.Recording,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetTranscriptRequest(proto.Message):
    r"""Request for GetTranscript method.

    Attributes:
        name (str):
            Required. Resource name of the transcript.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListTranscriptsRequest(proto.Message):
    r"""Request for ListTranscripts method.

    Attributes:
        parent (str):
            Required. Format: ``conferenceRecords/{conference_record}``
        page_size (int):
            Maximum number of transcripts to return. The
            service might return fewer than this value.
            If unspecified, at most 10 transcripts are
            returned. The maximum value is 100; values above
            100 are coerced to 100. Maximum might change in
            the future.
        page_token (str):
            Page token returned from previous List Call.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListTranscriptsResponse(proto.Message):
    r"""Response for ListTranscripts method.

    Attributes:
        transcripts (MutableSequence[google.apps.meet_v2beta.types.Transcript]):
            List of transcripts in one page.
        next_page_token (str):
            Token to be circulated back for further List
            call if current List doesn't include all the
            transcripts. Unset if all transcripts are
            returned.
    """

    @property
    def raw_page(self):
        return self

    transcripts: MutableSequence[resource.Transcript] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=resource.Transcript,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetTranscriptEntryRequest(proto.Message):
    r"""Request for GetTranscriptEntry method.

    Attributes:
        name (str):
            Required. Resource name of the ``TranscriptEntry``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListTranscriptEntriesRequest(proto.Message):
    r"""Request for ListTranscriptEntries method.

    Attributes:
        parent (str):
            Required. Format:
            ``conferenceRecords/{conference_record}/transcripts/{transcript}``
        page_size (int):
            Maximum number of entries to return. The
            service might return fewer than this value.
            If unspecified, at most 10 entries are returned.
            The maximum value is 100; values above 100 are
            coerced to 100. Maximum might change in the
            future.
        page_token (str):
            Page token returned from previous List Call.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListTranscriptEntriesResponse(proto.Message):
    r"""Response for ListTranscriptEntries method

    Attributes:
        transcript_entries (MutableSequence[google.apps.meet_v2beta.types.TranscriptEntry]):
            List of TranscriptEntries in one page.
        next_page_token (str):
            Token to be circulated back for further List
            call if current List doesn't include all the
            transcript entries. Unset if all entries are
            returned.
    """

    @property
    def raw_page(self):
        return self

    transcript_entries: MutableSequence[resource.TranscriptEntry] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=resource.TranscriptEntry,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
